<?php

/**
 * @file
 * Administrative functions for flag signup module.
 *
 */

define('FLAG_SIGNUP_MODERATION_TYPE_ROLE', 0);
define('FLAG_SIGNUP_MODERATION_TYPE_OG', 1);

/**
 * Admin settings form for moderation of signups.
 *
 * @param $form
 * @param $form_state
 * @return mixed
 */
function flag_signup_moderation_settings_form($form, &$form_state) {
  $form['flag_signup_moderation_type'] = array(
    '#type' => 'radios',
    '#title' => t('Moderation type'),
    '#default_value' => variable_get('flag_signup_moderation_type', FLAG_SIGNUP_MODERATION_TYPE_OG),
    '#options' => flag_signup_moderation_get_types(),
    '#description' => t('Select the type of moderation workflow.'),
  );

  if (module_exists('og')) {
    $form['og'] = array(
      '#type' => 'container',
      '#states' => array(
        'visible' => array(
          ':input[name="flag_signup_moderation_type"]' => array('value' => FLAG_SIGNUP_MODERATION_TYPE_OG),
        ),
      ),
    );
    $form['og']['flag_signup_moderation_moderators_group'] = array(
      '#type' => 'select',
      '#title' => t('Moderators group'),
      '#default_value' => variable_get('flag_signup_moderation_moderators_group', ''),
      '#options' => flag_signup_moderation_get_group_bundles(),
      '#description' => t('Users with group administration permission can validate signup flags for members of the group'),
    );

    $form['og']['flag_signup_moderation_users_group'] = array(
      '#type' => 'select',
      '#title' => t('Users group'),
      '#default_value' => variable_get('flag_signup_moderation_users_group', ''),
      '#options' => flag_signup_moderation_get_group_bundles(),
      '#description' => t('Add a moderator to the group and grant them group administration permission.'),
    );
  }
  $form['#submit'][] = 'flag_signup_moderation_settings_form_submit';
  return system_settings_form($form);
}

/**
 * Custom submit function for system settings form.
 *
 * @param $form
 * @param $form_state
 */
function flag_signup_moderation_settings_form_submit($form, &$form_state) {
  if ($form_state['values']['flag_signup_moderation_type'] == FLAG_SIGNUP_MODERATION_TYPE_OG) {
    $form_state['values']['flag_signup_moderation_moderators_group'] = '';
    $form_state['values']['flag_signup_moderation_users_group'] = '';
  }
}

/**
 * Get all moderation types.
 *
 * @return array
 */
function flag_signup_moderation_get_types() {
  $types = array();
  $types[FLAG_SIGNUP_MODERATION_TYPE_ROLE] = t('Role');
  if (module_exists('og')) {
    $types[FLAG_SIGNUP_MODERATION_TYPE_OG] = t('OG');
  }
  return $types;
}

/**
 * Get all OG bundles.
 *
 * @return array
 */
function flag_signup_moderation_get_group_bundles() {
  $group_bundles = array('' => t('- none -'));
  $bundles = og_get_all_group_bundle();
  return $group_bundles + $bundles['node'];
}
