<?php

  /**
   * @file
   *
   */

  class PeCourseExample extends PhpEduExampleMigration{
    public function __construct() {
      parent::__construct();
      $this->description = t('Import courses.');
      $this->dependencies = array('PeSectionExample'); //, 'PeCourseBookExample'
      // Create a map object for tracking the relationships between source rows
      $this->map = new MigrateSQLMap($this->machineName,
        array(
          'title' => array(
            'type'     => 'varchar',
            'length'   => 255,
            'not null' => TRUE,
          ),
        ),
        MigrateDestinationNode::getKeySchema()
      );

      // Create a MigrateSource object.
      $this->source = new MigrateSourceCSV(drupal_get_path('module', 'pe_migrate_example') . '/import/pe_course_example.csv', $this->csvcolumns(), array('header_rows' => 1));
      $this->destination = new MigrateDestinationNode('pe_course');

      $this->addFieldMapping('title', 'title');
      $this->addFieldMapping('body', 'body')
        ->arguments(array('format' => 'full_html'));
      $this->addFieldMapping('field_code', 'field_code');
      $this->addFieldMapping('field_section_id', 'field_section_id')
        ->sourceMigration(array('PeSectionExample'));
      $this->addFieldMapping('field_delivery_method', 'field_delivery_method');
      $this->addFieldMapping('field_hours', 'field_hours');
      $this->addFieldMapping('field_credits', 'field_credits');
      $this->addFieldMapping('field_image', 'field_image');
      $this->addFieldMapping('field_image:file_replace')
        ->defaultValue(FILE_EXISTS_REPLACE);
      $this->addFieldMapping('field_image:source_dir')
        ->defaultValue(drupal_get_path('module', 'pe_migrate_example') . '/import/images/courses');
      $this->addFieldMapping('uid', 'uid')->defaultValue(1);
      $this->addFieldMapping('is_new', 'is_new')->defaultValue(TRUE);
    }

    // rollback books added by rules for each course
    public function prepareRollback($entity_ids) {
      foreach($entity_ids as $entity_id) {
        $node = node_load($entity_id);
        if($node->field_course_book_id['und'][0]['target_id']) {
          node_delete($node->field_course_book_id['und'][0]['target_id']);
        }
      }
    }

    function csvcolumns() {
      $columns[0] = array('title', 'Title');
      $columns[1] = array('body', 'Body');
      $columns[2] = array('field_image', 'Image');
      $columns[3] = array('field_section_id', 'Department');
      $columns[4] = array('field_code', 'Code');
      $columns[5] = array('field_delivery_method', 'Delivery method');
      $columns[6] = array('field_hours', 'Hours');
      $columns[7] = array('field_credits', 'Credits');
      return $columns;
    }
  }