<?php

  /**
   * @file
   *
   */

  /**
   * Common features for all the migrations.
   */
  abstract class PhpEduExampleMigration extends Migration{

    public function processImport(array $options = array()) {
      parent::processImport($options = array());
      // Do not force menu rebuilding. Otherwise pathauto will try to rebuild
      // in each node_insert invocation.
      variable_set('menu_rebuild_needed', FALSE);
      // Avoid known line ending issue: drupal.org/node/1705850
      ini_set('auto_detect_line_endings', TRUE);
    }
  }

  class PeEduExample extends PhpEduExampleMigration{

    public function __construct() {
      parent::__construct();
      $this->description = t('Import Campus nodes.');

      // Create a map object for tracking the relationships between source rows
      $this->map = new MigrateSQLMap($this->machineName,
        array(
          'title' => array(
            'type'     => 'varchar',
            'length'   => 255,
            'not null' => TRUE,
          ),
        ),
        MigrateDestinationNode::getKeySchema()
      );

      // Create a MigrateSource object.
      $this->source = new MigrateSourceCSV(drupal_get_path('module', 'pe_migrate_example') . '/import/pe_edu_example.csv', $this->csvcolumns(), array('header_rows' => 1));

      $this->destination = new MigrateDestinationNode('pe_edu');

      // addressfield
      $arguments = array(
        'thoroughfare'        => array('source_field' => 'field_address__thoroughfare'),
        'locality'            => array('source_field' => 'field_address__locality'),
        'administrative_area' => array('source_field' => 'field_address__administrative_area'),
        'postal_code'         => array('source_field' => 'field_address__postal_code'),
      );

      $this->addFieldMapping('title', 'title');
      $this->addFieldMapping('body', 'body')->arguments(array('format' => 'full_html'));
      $this->addFieldMapping('path', 'path');
      // Add field mapping for active date which will be set when the row is being prepared in prepareRow()
      $this->addFieldMapping('field_active_date', 'field_active_date');
      $this->addFieldMapping(NULL, 'field_active_date__value');
      $this->addFieldMapping(NULL, 'field_active_date__value2');
      $this->addFieldMapping('field_institution_type', 'field_institution_type');
      $this->addFieldMapping('field_history', 'field_history');
      $this->addFieldMapping('field_main_location', 'field_main_location');
      $this->addFieldMapping('field_code', 'field_code');
      $this->addFieldMapping('field_address', 'field_address__country')
        ->arguments($arguments);
      $this->addFieldMapping(NULL, 'field_address__thoroughfare');
      $this->addFieldMapping(NULL, 'field_address__locality');
      $this->addFieldMapping(NULL, 'field_address__administrative_area');
      $this->addFieldMapping(NULL, 'field_address__postal_code');
      $this->addFieldMapping('field_phone', 'field_phone');
      $this->addFieldMapping('field_fax', 'field_fax');
      $this->addFieldMapping('field_url', 'field_url');
      $this->addFieldMapping('field_email', 'field_email');

      $this->addFieldMapping('field_image', 'field_image');
      $this->addFieldMapping('field_image:file_replace')
        ->defaultValue(FILE_EXISTS_REPLACE);
      $this->addFieldMapping('field_image:source_dir')
        ->defaultValue(drupal_get_path('module', 'pe_migrate_example') . '/import/images/edu');

      $this->addFieldMapping('uid', 'uid')->defaultValue(1);
      $this->addFieldMapping('is_new', 'is_new')->defaultValue(TRUE);
    }

    function csvcolumns() {
      $columns[0] = array('title', 'Title');
      $columns[1] = array('body', 'Body');
      $columns[2] = array('path', 'Path');
      $columns[3] = array('field_image', 'Image');
      $columns[4] = array('field_active_date__value', 'Active date (from)');
      $columns[5] = array('field_active_date__value2', 'Active date (to)');
      $columns[6] = array('field_institution_type', 'Institution type');
      $columns[7] = array('field_history', 'History');
      $columns[8] = array('field_main_location', 'Main location?');
      $columns[9] = array('field_code', 'Code');
      $columns[10] = array('field_address__thoroughfare', 'Street');
      $columns[11] = array('field_address__locality', 'Town/City');
      $columns[12] = array(
        'field_address__administrative_area',
        'State/Province'
      );
      $columns[13] = array('field_address__postal_code', 'Post code');
      $columns[14] = array('field_address__country', 'Country');
      $columns[15] = array('field_phone', 'Phone number');
      $columns[16] = array('field_fax', 'Fax');
      $columns[17] = array('field_url', 'URL');
      $columns[18] = array('field_email', 'Email');

      return $columns;
    }

    /**
     * This is run before addFieldMapping(). Tweak each row or skip before migrating
     *
     * @param $row
     *
     * @return bool
     */
    public function prepareRow($row) {
      if (parent::prepareRow($row) === FALSE) {
        return FALSE;
      }
      $date_data = array(
        'from' => drupal_strlen($row->field_active_date__value) ? $row->field_active_date__value : NULL,
        'to'   => drupal_strlen($row->field_active_date__value2) ? $row->field_active_date__value2 : NULL,
      );

      $row->field_active_date = drupal_json_encode($date_data);
      return TRUE;
    }

  }
