<?php

  /**
   * @file
   *
   */

  class PeProgramCourseExample extends PhpEduExampleMigration{
    public function __construct() {
      parent::__construct();
      $this->description = t('Import courses for programs.');
      $this->dependencies = array(
        'PeUserExample',
        'PeProgramExample',
        'PeCourseExample',
        'PeAcadYearExample',
        'PeAcadTermExample'
      );
      // Create a map object for tracking the relationships between source rows
      $this->map = new MigrateSQLMap($this->machineName,
        array(
          'title' => array(
            'type'     => 'varchar',
            'length'   => 255,
            'not null' => TRUE,
          ),
        ),
        MigrateDestinationNode::getKeySchema()
      );

      // Create a MigrateSource object.
      $this->source = new MigrateSourceCSV(drupal_get_path('module', 'pe_migrate_example') . '/import/pe_program_course_example.csv', $this->csvcolumns(), array('header_rows' => 1));
      $this->destination = new MigrateDestinationNode('pe_program_course');

      $this->addFieldMapping('title', 'title');
      $this->addFieldMapping('body', 'body')
        ->arguments(array('format' => 'full_html'));
      $this->addFieldMapping('field_acad_program_id', 'field_acad_program_id')
        ->sourceMigration(array('PeProgramExample'));
      $this->addFieldMapping('field_course_id', 'field_course_id')
        ->sourceMigration(array('PeCourseExample'));
      $this->addFieldMapping('field_acad_year_id', 'field_acad_year_id')
        ->sourceMigration(array('PeAcadYearExample'));
      $this->addFieldMapping('field_acad_term_id', 'field_acad_term_id')
        ->sourceMigration(array('PeAcadTermExample'));
      $this->addFieldMapping('field_course_weight', 'field_course_weight');
      $this->addFieldMapping('field_level', 'field_level');
      $this->addFieldMapping('field_prereq_id', 'field_prereq_id')
        ->separator('|')->sourceMigration(array('PeCourseExample'));
      $this->addFieldMapping('field_coreq_id', 'field_coreq_id')->separator('|')
        ->sourceMigration(array('PeCourseExample'));
      $this->addFieldMapping('field_nonreq_id', 'field_nonreq_id')
        ->separator('|')->sourceMigration(array('PeCourseExample'));
      $this->addFieldMapping('field_antireq_id', 'field_antireq_id')
        ->separator('|')->sourceMigration(array('PeCourseExample'));
      $this->addFieldMapping('field_teacher_id', 'field_teacher_id')
        ->separator(',')->sourceMigration(array('PeUserExample'));

      $this->addFieldMapping('uid', 'uid')->defaultValue(1);
      $this->addFieldMapping('is_new', 'is_new')->defaultValue(TRUE);
    }

    function csvcolumns() {
      $columns[0] = array('title', 'Title');
      $columns[1] = array('body', 'Remarks');
      $columns[2] = array('field_acad_program_id', 'Academic program');
      $columns[3] = array('field_course_id', 'Course');
      $columns[4] = array('field_acad_year_id', 'Academic year');
      $columns[5] = array('field_acad_term_id', 'Academic term');
      $columns[6] = array('field_course_weight', 'Course weight');
      $columns[7] = array('field_level', 'Level');
      $columns[8] = array('field_prereq_id', 'Pre-requisites');
      $columns[9] = array('field_coreq_id', 'Co-requisites');
      $columns[10] = array('field_nonreq_id', 'Non-requisites');
      $columns[11] = array('field_antireq_id', 'Anti-requisites');
      $columns[12] = array('field_teacher_id', 'Teacher(s)');
      return $columns;
    }
  }

  class PeProgramCourseGroupExample extends PhpEduExampleMigration{
    public function __construct() {
      parent::__construct();
      $this->description = t('Import groups for program courses.');
      $this->dependencies = array(
        'PeUserExample',
        'PeProgramCourseExample',
      );
      // Create a map object for tracking the relationships between source rows
      // title and field_teacher_id make each row unique (composite key)
      $this->map = new MigrateSQLMap($this->machineName,
        array(
          'title'            => array(
            'type'     => 'varchar',
            'length'   => 255,
            'not null' => TRUE,
          ),
          'field_teacher_id' => array(
            'type'     => 'varchar',
            'length'   => 60,
            'not null' => TRUE,
          ),
        ),
        MigrateDestinationNode::getKeySchema()
      );

      // Create a MigrateSource object.
      $this->source = new MigrateSourceCSV(drupal_get_path('module', 'pe_migrate_example') . '/import/pe_program_course_group_example.csv', $this->csvcolumns(), array('header_rows' => 1));
      $this->destination = new MigrateDestinationNode(NODE_TYPE_GROUP_COURSE);

      $this->addFieldMapping('title', 'title');
      $this->addFieldMapping('body', 'body')
        ->arguments(array('format' => 'full_html'));
      $this->addFieldMapping(NULL, 'field_teacher_id');
      $this->addFieldMapping(NULL, 'field_level');
      $this->addFieldMapping(NULL, 'field_student_id');

      $this->addFieldMapping('uid', 'field_teacher_id')
        ->sourceMigration('PeUserExample');
      $this->addFieldMapping('is_new', 'is_new')->defaultValue(TRUE);
    }

    function prepareRow($row) {
      if (parent::prepareRow($row) === FALSE) {
        return FALSE;
      }
      $row->title = sprintf("%s (%s)", $row->title, $row->field_teacher_id);
      $row->body = "<p>" . sprintf("Course group for %s", $row->title) . "</p>";
      return TRUE;
    }

    public function complete($entity, stdClass $row) {
      $query = new EntityFieldQuery;
      $query
        ->entityCondition('entity_type', 'user')
        ->propertyCondition('name', explode(',', $row->field_student_id), 'IN');
      $result = $query->execute();
      if(!empty($result['user']) && is_array($result['user'])) {
        foreach (array_keys($result['user']) as $uid) {
          og_group('node', $entity->nid, array('entity' => $uid));
        }
      }
    }

    function csvcolumns() {
      $columns[0] = array('title', 'Title');
      $columns[1] = array('field_teacher_id', 'Teacher');
      $columns[2] = array('field_level', 'Level');
      $columns[3] = array('field_student_id', 'Student');
      return $columns;
    }
  }
