<?php

  /**
   * @file
   *
   */


  class PeSectionExample extends PhpEduExampleMigration{

    public function __construct() {
      parent::__construct();
      $this->description = t('Import section (department) nodes.');
      $this->dependencies = array('PeEduExample');
      // Create a map object for tracking the relationships between source rows
      $this->map = new MigrateSQLMap($this->machineName,
        array(
          'title' => array(
            'type'     => 'varchar',
            'length'   => 255,
            'not null' => TRUE,
          ),
        ),
        MigrateDestinationNode::getKeySchema()
      );

      // Create a MigrateSource object.
      $this->source = new MigrateSourceCSV(drupal_get_path('module', 'pe_migrate_example') . '/import/pe_section_example.csv', $this->csvcolumns(), array('header_rows' => 1));

      $this->destination = new MigrateDestinationNode('pe_section');

      $this->addFieldMapping('title', 'title');
      $this->addFieldMapping('body', 'body')->arguments(array('format' => 'full_html'));
      $this->addFieldMapping('field_code', 'field_code');
      $this->addFieldMapping('field_parent_section', 'field_parent_section')->sourceMigration(array('PeSectionExample'));
      $this->addFieldMapping('field_edu_id', 'field_edu_id')->sourceMigration(array('PeEduExample'));
      $this->addFieldMapping('field_academic', 'field_academic');
      // Add field mapping for active date which will be set when the row is being prepared in prepareRow()
      $this->addFieldMapping('field_active_date', 'field_active_date');
      $this->addFieldMapping(NULL, 'field_active_date__value');
      $this->addFieldMapping(NULL, 'field_active_date__value2');
      $this->addFieldMapping('field_history', 'field_history')->arguments(array('format' => 'full_html'));
      $this->addFieldMapping('field_head_title', 'field_head_title');
      $this->addFieldMapping('field_ahead_title', 'field_ahead_title');
      $this->addFieldMapping('field_head', 'field_head');
      $this->addFieldMapping('field_ahead', 'field_ahead');
      $this->addFieldMapping('path', 'path');

      $this->addFieldMapping('field_image', 'field_image');
      $this->addFieldMapping('field_image:file_replace')->defaultValue(FILE_EXISTS_REPLACE);
      $this->addFieldMapping('field_image:source_dir')->defaultValue(drupal_get_path('module', 'pe_migrate_example') . '/import/images/sections');

      $this->addFieldMapping('uid', 'uid')->defaultValue(1);
      $this->addFieldMapping('is_new', 'is_new')->defaultValue(TRUE);
    }

    function csvcolumns() {
      $columns[0] = array('title', 'Title');
      $columns[1] = array('body', 'Body');
      $columns[2] = array('field_image', 'Image');
      $columns[3] = array('field_code', 'Code');
      $columns[4] = array('field_parent_section', 'Parent section');
      $columns[5] = array('field_edu_id', 'Location');
      $columns[6] = array('field_academic', 'Academic?');
      $columns[7] = array('field_active_date__value', 'Active date (from)');
      $columns[8] = array('field_active_date__value2', 'Active date (to)');
      $columns[9] = array('field_history', 'History');
      $columns[10] = array('field_head_title', 'Title (Head)');
      $columns[11] = array('field_ahead_title', 'Title (Asst. head)');
      $columns[12] = array('field_head', 'Head');
      $columns[13] = array('field_ahead', 'Asst. head');
      $columns[14] = array('path', 'Path');

      return $columns;
    }

    /**
     * This is run before addFieldMapping(). Tweak each row or skip before migrating
     *
     * @param $row
     *
     * @return bool
     */
    public function prepareRow($row) {
      if (parent::prepareRow($row) === FALSE) {
        return FALSE;
      }
      $date_data = array(
        'from' => drupal_strlen($row->field_active_date__value) ? $row->field_active_date__value : NULL,
        'to'   => drupal_strlen($row->field_active_date__value2) ? $row->field_active_date__value2 : NULL,
      );

      $row->field_active_date = drupal_json_encode($date_data);

      // TODO:
      $row->field_head = 0;
      $row->field_ahead = 0;

      return TRUE;
    }

  }
