<?php

  /**
   * @file
   *
   */

  abstract class PeUserExampleGeneric extends PhpEduExampleMigration{
    function csvcolumns() {
      $columns = array();
      $columns[0] = array('name', 'User name');
      $columns[1] = array('mail', 'User email');
      $columns[2] = array('pass', 'User password in plain text');
      $columns[3] = array('created', 'Date of creation');
      $columns[4] = array('picture', 'User\'s picture');
      $columns[5] = array('roles', 'Roles');
      $columns[6] = array('groups', 'Groups');
      $columns[7] = array('field_personal_title', 'Personal title');
      $columns[8] = array('field_firstname', 'First name');
      $columns[9] = array('field_middlename', 'Middle name(s)');
      $columns[10] = array('field_lastname', 'Last name');
      $columns[11] = array('field_image', 'Profile photo');
      $columns[12] = array('field_birth_date', 'Date of birth');
      $columns[13] = array('field_gender', 'Gender');
      $columns[14] = array('field_marital_status', 'Marital status');
      $columns[15] = array('field_address__thoroughfare', 'Street');
      $columns[16] = array('field_address__locality', 'Town/City');
      $columns[17] = array(
        'field_address__administrative_area',
        'State/Province'
      );
      $columns[18] = array('field_address__postal_code', 'Post code');
      $columns[19] = array('field_address__country', 'Country');
      $columns[20] = array('field_mobile', 'Mobile number');
      $columns[21] = array('field_phone', 'Phone number');
      $columns[22] = array('field_url', 'URL');
      $columns[23] = array('field_languages', 'Languages spoken');
      $columns[24] = array('field_interests', 'Interests');
      $columns[25] = array('uuid', 'UUID');

      return $columns;
    }
  }

  class PeUserExample extends PeUserExampleGeneric{

    public function __construct() {
      parent::__construct();
      $this->description = t('Import Users.');

      // Create a MigrateSource object.
      $this->source = new MigrateSourceCSV(drupal_get_path('module', 'pe_migrate_example') . '/import/pe_user_example.csv', $this->csvcolumns(), array('header_rows' => 1));
      $this->destination = new MigrateDestinationUser();
      $this->map = new MigrateSQLMap($this->machineName,
        array(
          'name' => array(
            'type'        => 'varchar',
            'length'      => 60,
            'not null'    => TRUE,
            'description' => t('Username')
          ),
        ),
        MigrateDestinationUser::getKeySchema()
      );

      // Mapped fields
      $this->addSimpleMappings(array('name'));
      $this->addFieldMapping('mail', 'mail')->defaultValue('')
        ->description(t('Email address'));
      $this->addFieldMapping('init')->defaultValue('')
        ->description(t('Email address used for initial account creation'));
      $this->addFieldMapping('pass', 'pass')->defaultValue('pass')
        ->description(t("User's password (plain text)"));
      $this->addFieldMapping('is_new')->defaultValue(TRUE)
        ->description(t('Build the new user (0|1)'));
      $this->addFieldMapping('role_names', 'role_names')
        ->defaultValue(DRUPAL_AUTHENTICATED_RID);
      $this->addFieldMapping('theme')->defaultValue('')
        ->description(t("User's default theme"));
      $this->addFieldMapping('signature')->defaultValue('')
        ->description(t("User's signature"));
      $this->addFieldMapping('signature_format')->defaultValue('filtered_html')
        ->description(t('Which filter applies to this signature'));
      $this->addFieldMapping('created')->defaultValue(time())
        ->description(t('UNIX timestamp of user creation date'));
      $this->addFieldMapping('access')->defaultValue(0)
        ->description(t('UNIX timestamp for previous time user accessed the site'));
      $this->addFieldMapping('login')->defaultValue(0)
        ->description(t('UNIX timestamp for user\'s last login'));
      $this->addFieldMapping('status')->defaultValue(1)
        ->description(t('Whether the user is active(1) or blocked(0)'));
      $this->addFieldMapping('timezone')->defaultValue(t('Europe/London'))
        ->description(t("User's time zone"));
      $this->addFieldMapping('language')->defaultValue(t('en'))
        ->description(t("User's default language"));
      $this->addFieldMapping('picture')->defaultValue(0)
        ->description(t('Avatar of the user'));
      $this->addFieldMapping(NULL, 'field_personal_title');
      $this->addFieldMapping(NULL, 'field_firstname');
      $this->addFieldMapping(NULL, 'field_middlename');
      $this->addFieldMapping(NULL, 'field_lastname');
      $this->addFieldMapping(NULL, 'field_image');
      $this->addFieldMapping(NULL, 'field_birth_date');
      $this->addFieldMapping(NULL, 'field_gender');
      $this->addFieldMapping(NULL, 'field_marital_status');
      $this->addFieldMapping(NULL, 'field_address__country');
      $this->addFieldMapping(NULL, 'field_address__thoroughfare');
      $this->addFieldMapping(NULL, 'field_address__locality');
      $this->addFieldMapping(NULL, 'field_address__administrative_area');
      $this->addFieldMapping(NULL, 'field_address__postal_code');
      $this->addFieldMapping(NULL, 'field_mobile');
      $this->addFieldMapping(NULL, 'field_phone');
      $this->addFieldMapping(NULL, 'field_url');
      $this->addFieldMapping(NULL, 'field_languages');
      $this->addFieldMapping(NULL, 'field_interests');
      $this->addFieldMapping(NULL, 'roles');
      $this->addFieldMapping(NULL, 'groups');
      $this->addFieldMapping(NULL, 'uuid');

      // Other handlers
      if (module_exists('path')) {
        $this->addFieldMapping('path')->defaultValue(NULL)
          ->description(t('Path alias'));
      }
      if (module_exists('pathauto')) {
        $this->addFieldMapping('pathauto')->defaultValue(1)
          ->description(t('Perform aliasing (set to 0 to prevent alias generation during migration)'));
      }
    }

    public function prepareRow($row) {
      // Always include this fragment at the beginning of every prepareRow()
      // implementation, so parent classes can ignore rows.
      if (parent::prepareRow($row) === FALSE) {
        return FALSE;
      }
      // role(s)
      $row->role_names = array("authenticated user");
      if (drupal_strlen($row->roles)) {
        $row->role_names = array_merge($row->role_names, explode(",", $row->roles));
      }
      if (drupal_strlen($row->groups)) {}
      return TRUE;
    }

  }

  /**
   * Profile2 field migration - main
   *
   */
  class PeUserMainProfileExample extends PeUserExampleGeneric{

    public function __construct() {
      parent::__construct();

      $this->description = t('Import main profile fields for users');
      $this->dependencies = array('PeUserExample');
      $this->source = new MigrateSourceCSV(drupal_get_path('module', 'pe_migrate_example') . '/import/pe_user_example.csv', $this->csvcolumns(), array('header_rows' => 1));
      $this->destination = new MigrateDestinationProfile2('main');
      $this->map = new MigrateSQLMap($this->machineName,
        array(
          'name' => array(
            'type'        => 'varchar',
            'length'      => 60,
            'not null'    => TRUE,
            'description' => t('Username')
          )
        ),
        MigrateDestinationProfile2::getKeySchema()
      );

      $arguments = array(
        'thoroughfare'        => array('source_field' => 'field_address__thoroughfare'),
        'locality'            => array('source_field' => 'field_address__locality'),
        'administrative_area' => array('source_field' => 'field_address__administrative_area'),
        'postal_code'         => array('source_field' => 'field_address__postal_code'),
      );

      // If your user migration class was named 'MyUserMigration', the string is 'MyUser'
      $this->addFieldMapping('uid', 'name')->sourceMigration('PeUserExample')
        ->description(t('The assignment of profile2 fields to the respective user'));
      $this->addFieldMapping('field_personal_title', 'field_personal_title');
      $this->addFieldMapping('field_firstname', 'field_firstname');
      $this->addFieldMapping('field_middlename', 'field_middlename');
      $this->addFieldMapping('field_lastname', 'field_lastname');
      $this->addFieldMapping('field_image', 'field_image');
      $this->addFieldMapping('field_birth_date', 'field_birth_date');
      $this->addFieldMapping('field_gender', 'field_gender');
      $this->addFieldMapping('field_marital_status', 'field_marital_status');
      $this->addFieldMapping('field_address', 'field_address__country')
        ->arguments($arguments);
      $this->addFieldMapping(NULL, 'field_address__thoroughfare');
      $this->addFieldMapping(NULL, 'field_address__locality');
      $this->addFieldMapping(NULL, 'field_address__administrative_area');
      $this->addFieldMapping(NULL, 'field_address__postal_code');
      $this->addFieldMapping('field_mobile', 'field_mobile');
      $this->addFieldMapping('field_phone', 'field_phone');
      $this->addFieldMapping('field_url', 'field_url');
      $this->addFieldMapping('field_languages', 'field_languages');
      $this->addFieldMapping('field_interests', 'field_interests');
      $this->addFieldMapping(NULL, 'uuid');

      // Other handlers
      if (module_exists('path')) {
        $this->addFieldMapping('path')->defaultValue(NULL)
          ->description(t('Path alias'));
      }

      // some internal fields
      $this->addFieldMapping('revision_uid')->defaultValue(1)
        ->description(t('The user ID of the user, who started the migration'));
      $this->addFieldMapping('language')->defaultValue(t('en'))
        ->description(t("The default language of the user (e.g. 'en', 'fr', 'de')"));
    }

    public function prepareRow($row) {
      // Always include this fragment at the beginning of every prepareRow()
      // implementation, so parent classes can ignore rows.
      if (parent::prepareRow($row) === FALSE) {
        return FALSE;
      }
      // interest(s)
      if (drupal_strlen($row->field_interests)) {
        $row->field_interests = explode(",", $row->field_interests);
      }
      // language(s)
      if (drupal_strlen($row->field_languages)) {
        $row->field_languages = explode(",", $row->field_languages);
      }
      return TRUE;
    }
  }

  /**
   * Profile2 field migration - student
   *
   */
  class PeUserStudentProfileExample extends PeUserExampleGeneric{

    public function __construct() {
      parent::__construct();

      $this->description = t('Import profile fields for students');
      $this->dependencies = array(
        'PeUserExample',
        'PeUserMainProfileExample',
        'PeProgramExample'
      );
      $this->source = new MigrateSourceCSV(drupal_get_path('module', 'pe_migrate_example') . '/import/pe_user_profile_student_example.csv', $this->csvcolumns(), array('header_rows' => 1));
      $this->destination = new MigrateDestinationProfile2('student');
      $this->map = new MigrateSQLMap($this->machineName,
        array(
          'name' => array(
            'type'        => 'varchar',
            'length'      => 60,
            'not null'    => TRUE,
            'description' => t('Username')
          )
        ),
        MigrateDestinationProfile2::getKeySchema()
      );

      // If your user migration class was named 'MyUserMigration', the string is 'MyUser'
      $this->addFieldMapping('uid', 'name')->sourceMigration('PeUserExample')
        ->description(t('The assignment of profile2 fields to the respective user'));
      $this->addFieldMapping(NULL, 'name');
      $this->addFieldMapping(NULL, 'uuid');
      $this->addFieldMapping(NULL, 'field_personal_title');
      $this->addFieldMapping(NULL, 'field_firstname');
      $this->addFieldMapping(NULL, 'field_lastname');
      $this->addFieldMapping('field_acad_program_id', 'field_acad_program_id')
        ->sourceMigration(array('PeProgramExample'));
      $this->addFieldMapping('field_level', 'field_level');
      $this->addFieldMapping(NULL, 'field_entry_year_id'); // TODOL:
      $this->addFieldMapping('field_matriculation_number', 'field_matriculation_number');
      $this->addFieldMapping('field_entry_mode', 'field_entry_mode');
    }

    public function prepareRow($row) {
      // Always include this fragment at the beginning of every prepareRow()
      // implementation, so parent classes can ignore rows.
      if (parent::prepareRow($row) === FALSE) {
        return FALSE;
      }

      // a student must have an academic program
      if (!drupal_strlen($row->field_acad_program_id)) {
        return FALSE;
      }
    }

    function csvcolumns() {
      $columns = array();
      $columns[0] = array('name', 'Username');
      $columns[1] = array('uuid', 'UUID');
      $columns[2] = array('field_personal_title', 'Personal title');
      $columns[3] = array('field_firstname', 'First name');
      $columns[4] = array('field_lastname', 'Last name');
      $columns[5] = array('field_acad_program_id', 'Academic programme');
      $columns[6] = array('field_level', 'Study level');
      $columns[7] = array('field_entry_year_id', 'Year of Entry');
      $columns[8] = array(
        'field_matriculation_number',
        'Matriculation/Student Identification number'
      );
      $columns[9] = array('field_entry_mode', 'Mode of Entry');

      return $columns;
    }

  }


  /**
   * Profile2 field migration - staff
   *
   */
  class PeUserStaffProfileExample extends PeUserExampleGeneric{

    public function __construct() {
      parent::__construct();

      $this->description = t('Import profile fields for staff');
      $this->dependencies = array('PeUserExample', 'PeUserMainProfileExample', 'PeAcadYearExample', 'PeSectionExample');
      $this->source = new MigrateSourceCSV(drupal_get_path('module', 'pe_migrate_example') . '/import/pe_user_profile_staff_example.csv', $this->csvcolumns(), array('header_rows' => 1));
      $this->destination = new MigrateDestinationProfile2('staff');
      $this->map = new MigrateSQLMap($this->machineName,
        array(
          'name' => array(
            'type'        => 'varchar',
            'length'      => 60,
            'not null'    => TRUE,
            'description' => t('Username')
          )
        ),
        MigrateDestinationProfile2::getKeySchema()
      );

      // If your user migration class was named 'MyUserMigration', the string is 'MyUser'
      $this->addFieldMapping('uid', 'name')->sourceMigration('PeUserExample')
        ->description(t('The assignment of profile2 fields to the respective user'));
      $this->addFieldMapping(NULL, 'name');
      $this->addFieldMapping(NULL, 'roles');
      $this->addFieldMapping(NULL, 'uuid');
      $this->addFieldMapping(NULL, 'field_personal_title');
      $this->addFieldMapping(NULL, 'field_firstname');
      $this->addFieldMapping(NULL, 'field_lastname');
      $this->addFieldMapping('field_section_id', 'field_section_id')->sourceMigration('PeSectionExample');
      $this->addFieldMapping('field_position', 'field_position');
      $this->addFieldMapping('field_academic', 'field_academic');
      $this->addFieldMapping('field_staff_number', 'field_staff_number');
      $this->addFieldMapping('field_employment_year_id', 'field_employment_year_id')->sourceMigration('PeAcadYearExample');

    }

    public function prepareRow($row) {
      // Always include this fragment at the beginning of every prepareRow()
      // implementation, so parent classes can ignore rows.
      if (parent::prepareRow($row) === FALSE) {
        return FALSE;
      }

      // a staff must have a department
      if (!drupal_strlen($row->field_section_id)) {
        return FALSE;
      }
    }

    function csvcolumns() {
      $columns = array();
      $columns[0] = array('name', 'Username');
      $columns[1] = array('roles', 'Roles');
      $columns[2] = array('uuid', 'UUID');
      $columns[3] = array('field_personal_title', 'Personal title');
      $columns[4] = array('field_firstname', 'First name');
      $columns[5] = array('field_lastname', 'Last name');
      $columns[6] = array('field_section_id', 'Department');
      $columns[7] = array('field_position', 'Position');
      $columns[8] = array('field_academic', 'Academic?');
      $columns[9] = array('field_staff_number', 'Staff Identification number');
      $columns[10] = array('field_employment_year_id', 'Year of Employment');
      return $columns;
    }

  }

// TODOL:
//class PeUserProfileEducationBackgroundExample extends PhpEduExampleMigration {
//  public function __construct() {
//    parent::__construct();
//
//  }
//}

// TODOL:
//class PeUserProfileEmploymentHistoryExample extends PhpEduExampleMigration {
//  public function __construct() {
//    parent::__construct();
//
//  }
//}


  class PeUserAlumnusProfileExample extends PhpEduExampleMigration{
    public function __construct() {
      parent::__construct();

      $this->description = t('Import profile fields for staff');
      $this->dependencies = array('PeUserExample', 'PeUserMainProfileExample');
      $this->source = new MigrateSourceCSV(drupal_get_path('module', 'pe_migrate_example') . '/import/pe_user_profile_alumnus.csv', $this->csvcolumns(), array('header_rows' => 1));
      $this->destination = new MigrateDestinationProfile2('alumnus');
      $this->map = new MigrateSQLMap($this->machineName,
        array(
          'uuid' => array(
            'type'        => 'varchar',
            'length'      => 36,
            'not null'    => TRUE,
            'description' => t('UUID of an alumnus profile')
          )
        ),
        MigrateDestinationProfile2::getKeySchema()
      );

      $this->addFieldMapping('uid', 'name')->sourceMigration('PeUserExample')
        ->description(t('The assignment of profile2 fields to the respective user'));
      $this->addFieldMapping(NULL, 'name');
      $this->addFieldMapping(NULL, 'uuid');
      $this->addFieldMapping(NULL, 'field_personal_title');
      $this->addFieldMapping(NULL, 'field_firstname');
      $this->addFieldMapping(NULL, 'field_lastname');
      $this->addFieldMapping('field_alumni_association_active', 'field_alumni_association_active');

    }

    function csvcolumns() {
      $columns = array();
      $columns[0] = array('name', 'Username');
      $columns[1] = array('uuid', 'UUID');
      $columns[2] = array('field_personal_title', 'Personal title');
      $columns[3] = array('field_firstname', 'First name');
      $columns[4] = array('field_lastname', 'Last name');
      $columns[5] = array(
        'field_alumni_association_active',
        'Alumni association membership'
      );
      return $columns;
    }
  }


  /**
   * Class PeUserProfileStudyExample
   *
   * Alumni study records
   */
  class PeUserProfileFieldStudyExample extends PhpEduExampleMigration{
    public function __construct() {
      parent::__construct();

      $this->description = t('Import field collections for alumnus profile');
      $this->dependencies = array(
        'PeProgramExample',
        'PeAcadYearExample',
        'PeUserAlumnusProfileExample'
      );
      $this->source = new MigrateSourceCSV(drupal_get_path('module', 'pe_migrate_example') . '/import/pe_user_profile_alumnus_field_study.csv', $this->csvcolumns(), array('header_rows' => 1));
      $this->map = new MigrateSQLMap($this->machineName,
        array(
          'uuid' => array(
            'type'        => 'varchar',
            'length'      => 36,
            'not null'    => TRUE,
            'description' => t('UUID of a field collection instance')
          )
        ),
        MigrateDestinationProfile2::getKeySchema()
      );

      $this->destination = new MigrateDestinationFieldCollection(
        'field_study',
        array('host_entity_type' => 'profile2')
      );

      $this->addFieldMapping('host_entity_id', 'uuid')
        ->sourceMigration('PeUserAlumnusProfileExample');
      $this->addFieldMapping(NULL, 'name');
      $this->addFieldMapping(NULL, 'uuid');
      $this->addFieldMapping(NULL, 'field_personal_title');
      $this->addFieldMapping(NULL, 'field_firstname');
      $this->addFieldMapping(NULL, 'field_lastname');
      $this->addFieldMapping('field_acad_program_id', 'field_acad_program_id')
        ->sourceMigration(array('PeProgramExample'));
      $this
        ->addFieldMapping('field_graduation_year_id', 'field_graduation_year_id')
        ->sourceMigration(array('PeAcadYearExample'));

    }

    function csvcolumns() {
      $columns = array();
      $columns[0] = array('name', 'Username');
      $columns[1] = array('uuid', 'UUID');
      $columns[2] = array('field_personal_title', 'Personal title');
      $columns[3] = array('field_firstname', 'First name');
      $columns[4] = array('field_lastname', 'Last name');
      $columns[5] = array('field_acad_program_id', 'Program');
      $columns[6] = array('field_graduation_year_id', 'Year of Graduation');
      return $columns;
    }

  }

// TODOL:
//  class PeUserProfileRelationshipExample extends PhpEduExampleMigration {
//    public function __construct() {
//      parent::__construct();
//
//    }
//  }

  class PeGroupMembershipExample extends PhpEduExampleMigration{

    public function __construct() {
      parent::__construct();

      $this->description = t('Import users into basic groups');
      $this->dependencies = array(
        'PeUserExample',
        'PeGroupExample',
        'PeProgramExample'
      );
      $this->source = new MigrateSourceCSV(drupal_get_path('module', 'pe_migrate_example') . '/import/pe_user_groups_example.csv', $this->csvcolumns(), array('header_rows' => 1));
      $this->map = new MigrateSQLMap($this->machineName,
        array(
          'uuid' => array(
            'type'        => 'varchar',
            'length'      => 36,
            'not null'    => TRUE,
            'description' => t('Username')
          )
        ),
        MigrateDestinationOGMembership::getKeySchema()
      );

      $this->destination = new MigrateDestinationOGMembership();

      $this->addFieldMapping('group_type', NULL)->defaultValue('node');
      $this->addFieldMapping('gid', 'group')->sourceMigration('PeGroupExample');
      $this->addFieldMapping('entity_type', NULL)->defaultValue('user');
      $this->addFieldMapping('etid', 'name')->sourceMigration('PeUserExample');
      $this->addFieldMapping('group_role', 'group_role'); // TODO:
      $this->addFieldMapping(NULL, 'name');
      $this->addFieldMapping(NULL, 'uuid');
      $this->addFieldMapping(NULL, 'uuid_user');
      $this->addFieldMapping(NULL, 'field_personal_title');
      $this->addFieldMapping(NULL, 'field_firstname');
      $this->addFieldMapping(NULL, 'field_lastname');
      $this->addFieldMapping(NULL, 'group');
      $this->addFieldMapping(NULL, 'name');
    }

    function csvcolumns() {
      $columns = array();
      $columns[0] = array('uuid', 'UUID');
      $columns[1] = array('name', 'Username');
      $columns[2] = array('field_personal_title', 'Personal title');
      $columns[3] = array('field_firstname', 'First name');
      $columns[4] = array('field_lastname', 'Last name');
      $columns[5] = array('group', 'Group');
      $columns[6] = array('group_role', 'Group role');
      $columns[7] = array('uuid_user', 'User\'s UUID');
      return $columns;
    }

  }