<?php

  /**
   * @file
   *
   */

  /**
   * Common features for all the migrations.
   */

  class PeAcadYearExample extends PhpEduExampleMigration{

    public function __construct() {
      parent::__construct();
      $this->description = t('Import Academic years.');

      // Create a map object for tracking the relationships between source rows
      $this->map = new MigrateSQLMap($this->machineName,
        array(
          'title' => array(
            'type'     => 'varchar',
            'length'   => 255,
            'not null' => TRUE,
          ),
        ),
        MigrateDestinationNode::getKeySchema()
      );

      // Create a MigrateSource object.
      $this->source = new MigrateSourceCSV(drupal_get_path('module', 'pe_migrate_example') . '/import/pe_acad_year_example.csv', $this->csvcolumns(), array('header_rows' => 1));

      $this->destination = new MigrateDestinationNode('pe_acad_year');

      $this->addFieldMapping('title', 'title');
      $this->addFieldMapping('body', 'body')->arguments(array('format' => 'full_html'));
      $this->addFieldMapping('field_active_date', 'field_active_date');
      $this->addFieldMapping(NULL, 'field_active_date__value');
      $this->addFieldMapping(NULL, 'field_active_date__value2');

      $this->addFieldMapping('uid', 'uid')->defaultValue(1);
      $this->addFieldMapping('is_new', 'is_new')->defaultValue(TRUE);
    }

    function csvcolumns() {
      $columns[0] = array('title', 'Title');
      $columns[1] = array('field_active_date__value', 'Active date (from)');
      $columns[2] = array('field_active_date__value2', 'Active date (to)');
      $columns[3] = array('body', 'Body');

      return $columns;
    }

    /**
     * This is run before addFieldMapping(). Tweak each row or skip before migrating
     *
     * @param $row
     *
     * @return bool
     */
    public function prepareRow($row) {
      if (parent::prepareRow($row) === FALSE) {
        return FALSE;
      }
      $date_data = array(
        'from' => drupal_strlen($row->field_active_date__value) ? $row->field_active_date__value : NULL,
        'to'   => drupal_strlen($row->field_active_date__value2) ? $row->field_active_date__value2 : NULL,
      );

      $row->field_active_date = drupal_json_encode($date_data);
      return TRUE;
    }

  }
